@@ -58,11 +58,7 @@ where
 
 /// Print all the lines from the given `input` to `out`, with all mangled C++
 /// symbols replaced with their demangled form.
-fn demangle_all<R, W>(
-    input: &mut R,
-    out: &mut W,
-    options: &DemangleOptions,
-) -> io::Result<()>
+fn demangle_all<R, W>(input: &mut R, out: &mut W, options: &DemangleOptions) -> io::Result<()>
 where
     R: BufRead,
     W: Write,
@@ -81,7 +77,9 @@ fn main() {
     let matches = App::new("cppfilt")
         .version(crate_version!())
         .author(crate_authors!())
-        .about("A c++filt clone as an example of how to use the cpp_demangle crate!")
+        .about(
+            "A c++filt clone as an example of how to use the cpp_demangle crate!",
+        )
         .arg(
             Arg::with_name("noparams")
                 .short("p")
@@ -104,9 +102,7 @@ fn main() {
     let stderr = io::stderr();
     let mut stderr = stderr.lock();
 
-    let options = DemangleOptions {
-        no_params: matches.is_present("noparams"),
-    };
+    let options = DemangleOptions { no_params: matches.is_present("noparams") };
 
     let demangle_result = if let Some(names) = matches.values_of("mangled_names") {
         let mut input = Cursor::new(names.fold(String::new(), |mut accumulated, name| {
